package cz.cvut.kbss.bookstore.config;

import org.springframework.web.context.request.RequestContextListener;
import org.springframework.web.servlet.support.AbstractAnnotationConfigDispatcherServletInitializer;

import javax.faces.webapp.FacesServlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletRegistration;

/**
 * If a class implementing {@link org.springframework.web.WebApplicationInitializer} is found on application deploy, it
 * is called.
 * <p>
 * This class is such implementation and is used to start up the Spring context.
 */
public class DispatcherServletInitializer extends AbstractAnnotationConfigDispatcherServletInitializer {

    /**
     * Spring configuration class.
     * <p>
     * We are using the main one, which in turn imports other configurations.
     */
    @Override
    protected Class<?>[] getRootConfigClasses() {
        return new Class<?>[]{WebAppConfig.class};
    }

    @Override
    protected Class<?>[] getServletConfigClasses() {
        return null;
    }

    /**
     * Process all incoming requests.
     */
    @Override
    protected String[] getServletMappings() {
        return new String[]{"/"};
    }

    @Override
    public void onStartup(ServletContext servletContext) throws ServletException {
        System.out.println("****** Application Context Initialization ******");
        // Forces the JSF implementation to load configuration and start
        servletContext.setInitParameter("com.sun.faces.forceLoadConfiguration", Boolean.TRUE.toString());

        // Causes Spring to process incoming servlet requests
        servletContext.addListener(new RequestContextListener());
        // Add a Java Server Faces servlet
        ServletRegistration.Dynamic facesServlet = servletContext.addServlet("FacesServlet", FacesServlet.class);
        facesServlet.setLoadOnStartup(1);
        facesServlet.addMapping("*.xhtml");

        super.onStartup(servletContext);
    }
}
